
#ifndef AKONADI_KABC_EXPORT_H
#define AKONADI_KABC_EXPORT_H

#ifdef AKONADI_KABC_STATIC_DEFINE
#  define AKONADI_KABC_EXPORT
#  define AKONADI_KABC_NO_EXPORT
#else
#  ifndef AKONADI_KABC_EXPORT
#    ifdef akonadi_kabc
        /* We are building this library */
#      define AKONADI_KABC_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define AKONADI_KABC_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef AKONADI_KABC_NO_EXPORT
#    define AKONADI_KABC_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef AKONADI_KABC_DEPRECATED
#  define AKONADI_KABC_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef AKONADI_KABC_DEPRECATED_EXPORT
#  define AKONADI_KABC_DEPRECATED_EXPORT AKONADI_KABC_EXPORT AKONADI_KABC_DEPRECATED
#endif

#ifndef AKONADI_KABC_DEPRECATED_NO_EXPORT
#  define AKONADI_KABC_DEPRECATED_NO_EXPORT AKONADI_KABC_NO_EXPORT AKONADI_KABC_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef AKONADI_KABC_NO_DEPRECATED
#    define AKONADI_KABC_NO_DEPRECATED
#  endif
#endif

#endif /* AKONADI_KABC_EXPORT_H */
